# Information

<mark>**regease**</mark> is a simple **Python** module to simplify the so-called regular expressions. It includes validation of complex _passwords_ , simple and common  _usernames_ and the _Email Addressess_

---

>It will make your life easier....

To import the module:

```python

import regease

```

# OR

```python
from regease import emailVd, usernameVd, passwordVd

```

